@@ -1,5 +1,5 @@
 /* test-parser.c --- Self tests of DIGEST-MD5 parser & printer.
- * Copyright (C) 2004-2020 Simon Josefsson
+ * Copyright (C) 2004-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -35,7 +35,7 @@
 #include "gc.h"
 
 int
-main (int argc, char *argv[])
+main (void)
 {
   digest_md5_challenge c;
   digest_md5_response r;
@@ -91,7 +91,8 @@ main (int argc, char *argv[])
     rc = digest_md5_parse_challenge (token, 0, &c);
     if (rc != 0)
       abort ();
-    printf ("qop %02x ciphers %02x: %s\n", c.qops, c.ciphers,
+    printf ("qop %02x ciphers %02x: %s\n",
+	    (unsigned) c.qops, (unsigned) c.ciphers,
 	    (c.qops == 5 && c.ciphers == 1) ? "PASS" : "FAILURE");
     tmp = digest_md5_print_challenge (&c);
     if (!tmp)
