@@ -1,5 +1,5 @@
 /* server.c --- Non-standard SASL mechanism LOGIN, server side.
- * Copyright (C) 2002-2020 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -44,7 +44,7 @@ struct _Gsasl_login_server_state
 #define CHALLENGE_PASSWORD "Password"
 
 int
-_gsasl_login_server_start (Gsasl_session * sctx, void **mech_data)
+_gsasl_login_server_start (Gsasl_session * sctx _GL_UNUSED, void **mech_data)
 {
   struct _Gsasl_login_server_state *state;
 
@@ -143,7 +143,7 @@ _gsasl_login_server_step (Gsasl_session * sctx,
 }
 
 void
-_gsasl_login_server_finish (Gsasl_session * sctx, void *mech_data)
+_gsasl_login_server_finish (Gsasl_session * sctx _GL_UNUSED, void *mech_data)
 {
   struct _Gsasl_login_server_state *state = mech_data;
 
