@@ -1,5 +1,5 @@
 /* server.c --- SASL mechanism SECURID from RFC 2808, server side.
- * Copyright (C) 2002-2020 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -38,7 +38,7 @@
 
 int
 _gsasl_securid_server_step (Gsasl_session * sctx,
-			    void *mech_data,
+			    void *mech_data _GL_UNUSED,
 			    const char *input, size_t input_len,
 			    char **output, size_t *output_len)
 {
