@@ -1,5 +1,5 @@
 /* xfinish.c --- Finish libgsasl session.
- * Copyright (C) 2002-2020 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -63,6 +63,8 @@ gsasl_finish (Gsasl_session * sctx)
   free (sctx->scram_iter);
   free (sctx->scram_salt);
   free (sctx->scram_salted_password);
+  free (sctx->scram_serverkey);
+  free (sctx->scram_storedkey);
   free (sctx->cb_tls_unique);
   free (sctx->saml20_idp_identifier);
   free (sctx->saml20_redirect_url);
