@@ -1,5 +1,5 @@
 /* smtp.c --- Implement SMTP profile of SASL login.
- * Copyright (C) 2002-2020 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -76,7 +76,7 @@ smtp_select_mechanism (char **mechlist)
   if (args_info.server_flag)
     {
       if (!args_info.quiet_given)
-	fprintf (stderr, _("Chose SASL mechanisms:\n"));
+	fprintf (stderr, _("Input list of SASL mechanisms:\n"));
       if (!readln (&in))
 	return 0;
       *mechlist = in;
